==> code_saturne-8.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__matrix_8h.js <==
var cs__matrix_8h =
[
    [ "cs_matrix_row_info_t", "structcs__matrix__row__info__t.html", "structcs__matrix__row__info__t" ],
    [ "cs_matrix_structure_t", "cs__matrix_8h.html#a3f726affcdb381ba839a195b62acbb92", null ],
    [ "cs_matrix_t", "cs__matrix_8h.html#a53c593fb2c03dfc5eee5c9a54d895cb4", null ],
    [ "cs_matrix_variant_t", "cs__matrix_8h.html#a08cf016a0506bb404109a18e8e3bb2a5", null ],
    [ "cs_matrix_fill_type_t", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310", [
      [ "CS_MATRIX_SCALAR", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310ab9d5f9e1068cc673a690186129e092e6", null ],
      [ "CS_MATRIX_SCALAR_SYM", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310acada4d09e2a95e0b4f850e672c8887d0", null ],
      [ "CS_MATRIX_BLOCK_D", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310abb2fea01a93c8dd923217e1dd3dacf37", null ],
      [ "CS_MATRIX_BLOCK_D_66", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310a0fe52150bd1561197edcd2a99f910d4a", null ],
      [ "CS_MATRIX_BLOCK_D_SYM", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310ad25d63237d2364ef032500bfef1fefb6", null ],
      [ "CS_MATRIX_BLOCK", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310abd9236e84a7886bc6dfe277e36d89863", null ],
      [ "CS_MATRIX_N_FILL_TYPES", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310a25ac45e1c0bd00980f5d634debf8b2b4", null ]
    ] ],
    [ "cs_matrix_spmv_type_t", "cs__matrix_8h.html#a4469a8e1bec6b446d8bf524f31713c95", [
      [ "CS_MATRIX_SPMV", "cs__matrix_8h.html#a4469a8e1bec6b446d8bf524f31713c95a3463bd22a53462ab0a6b9ff0b57e5e00", null ],
      [ "CS_MATRIX_SPMV_E", "cs__matrix_8h.html#a4469a8e1bec6b446d8bf524f31713c95a8c4a495ce8063fe98be6aa9f1551d4d3", null ],
      [ "CS_MATRIX_SPMV_N_TYPES", "cs__matrix_8h.html#a4469a8e1bec6b446d8bf524f31713c95a0add080683610fa2efb06e2efd16ad82", null ]
    ] ],
    [ "cs_matrix_type_t", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997", [
      [ "CS_MATRIX_NATIVE", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997abd7a07b24725c3c34588ae88adc9b990", null ],
      [ "CS_MATRIX_CSR", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997a1365d45fd66cbc4d1c4e7c5f5602cf2f", null ],
      [ "CS_MATRIX_MSR", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997a337c2f76d768d376d33d8975bf0f487e", null ],
      [ "CS_MATRIX_DIST", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997ac5871f65fee08406348feab4a6436d5b", null ],
      [ "CS_MATRIX_N_BUILTIN_TYPES", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997ae4b62c68b544fa6f0bf2457a0b242ac2", null ],
      [ "CS_MATRIX_N_TYPES", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997a6f7ed530ef30b9cb1f192f043ba999ff", null ]
    ] ],
    [ "cs_matrix_apply_variant", "cs__matrix_8h.html#a8336ea1e2bb9661e28caab372475cb53", null ],
    [ "cs_matrix_assembler_values_init", "cs__matrix_8h.html#ad7bb9036893ac6444522e9c509ee9630", null ],
    [ "cs_matrix_copy_coefficients", "cs__matrix_8h.html#a1d6c57497d1523e9720d9f1747d77754", null ],
    [ "cs_matrix_copy_diagonal", "cs__matrix_8h.html#a36131c936a1779dc8babf8f09e2e4a8e", null ],
    [ "cs_matrix_create", "cs__matrix_8h.html#a73aa26bfb5835175f3a0d9bf3716d949", null ],
    [ "cs_matrix_create_by_copy", "cs__matrix_8h.html#a6837b79c6cada564a7915205107633b1", null ],
    [ "cs_matrix_create_by_local_restrict", "cs__matrix_8h.html#ae696bb416b5e92e66d4d23e38f86d6e6", null ],
    [ "cs_matrix_create_from_assembler", "cs__matrix_8h.html#ab7b3f1df97080571955b082ba73a06b5", null ],
    [ "cs_matrix_destroy", "cs__matrix_8h.html#a633b7979992bdf4c3577735862a1975b", null ],
    [ "cs_matrix_get_alloc_mode", "cs__matrix_8h.html#a8606b1bd075ad019e8ee515c6e57120f", null ],
    [ "cs_matrix_get_csr_arrays", "cs__matrix_8h.html#a8553ace49ccaf0d3181b9bd860e9b5db", null ],
    [ "cs_matrix_get_diag_block_size", "cs__matrix_8h.html#ac3af04d2c3b246fa3629662953cc313d", null ],
    [ "cs_matrix_get_diagonal", "cs__matrix_8h.html#a419d88f77d3c32610efc18645d6e613d", null ],
    [ "cs_matrix_get_extra_diag_block_size", "cs__matrix_8h.html#a406514787577b41a6c2247f6c0daf236", null ],
    [ "cs_matrix_get_extra_diagonal", "cs__matrix_8h.html#a6b62a48c0788d14d9a27458d0817f60f", null ],
    [ "cs_matrix_get_fill_type", "cs__matrix_8h.html#a68debb26743a812111e1bec78d7d17f2", null ],
    [ "cs_matrix_get_halo", "cs__matrix_8h.html#ab127f615e04b4eac829475a995787fd3", null ],
    [ "cs_matrix_get_l_range", "cs__matrix_8h.html#af74adf5dfe86dfb17510e76e551d8600", null ],
    [ "cs_matrix_get_msr_arrays", "cs__matrix_8h.html#a98cfe74b97c8ab6b8e54abef05a55ab1", null ],
    [ "cs_matrix_get_n_columns", "cs__matrix_8h.html#ae86688001d80341b85d58c8825018b2f", null ],
    [ "cs_matrix_get_n_entries", "cs__matrix_8h.html#a54961bf406b63762241dad3544158efd", null ],
    [ "cs_matrix_get_n_rows", "cs__matrix_8h.html#ae4681eaf0396bc1e723b7f4d3ebd4377", null ],
    [ "cs_matrix_get_native_arrays", "cs__matrix_8h.html#ae9f4142ccd2418b11db757202dbfc418", null ],
    [ "cs_matrix_get_row", "cs__matrix_8h.html#adc6fdbddaced8b5c756df36386f5e1e4", null ],
    [ "cs_matrix_get_type", "cs__matrix_8h.html#adfe3a7a23fddd7c31ff1c071ec51b489", null ],
    [ "cs_matrix_get_type_fullname", "cs__matrix_8h.html#a32eb97c780d714d225f867eca6fdcac7", null ],
    [ "cs_matrix_get_type_name", "cs__matrix_8h.html#ac2a38b40b275f2d1d178f80a2f0e4755", null ],
    [ "cs_matrix_is_mapped_from_native", "cs__matrix_8h.html#ad1e0fd14b5629863a6830f8fc4a8d65e", null ],
    [ "cs_matrix_is_symmetric", "cs__matrix_8h.html#a0d607988a2fc1e3491bae9d14a633929", null ],
    [ "cs_matrix_pre_vector_multiply_sync", "cs__matrix_8h.html#ac6cb5803fa6d1b9bd5651ab814b468fe", null ],
    [ "cs_matrix_release_coefficients", "cs__matrix_8h.html#ad8cc5a171f95e3c78473516a6080a8d6", null ],
    [ "cs_matrix_row_finalize", "cs__matrix_8h.html#a0050a6f62ba44ecc04d003f9c33be385", null ],
    [ "cs_matrix_row_init", "cs__matrix_8h.html#a95921370bbdca497111adf4a6332e304", null ],
    [ "cs_matrix_set_alloc_mode", "cs__matrix_8h.html#a84a97ba577aa871c439bb73dbf6233e8", null ],
    [ "cs_matrix_set_coefficients", "cs__matrix_8h.html#a1dac07f4baf766157cf15bc2db1f42da", null ],
    [ "cs_matrix_structure_create", "cs__matrix_8h.html#a20399038485d71ab179a652b524e2f5b", null ],
    [ "cs_matrix_structure_create_from_assembler", "cs__matrix_8h.html#affee236ad9bb96cced27a40eccee05d9", null ],
    [ "cs_matrix_structure_create_msr", "cs__matrix_8h.html#a9d4398178519ce533a861895002ccc7e", null ],
    [ "cs_matrix_structure_create_msr_shared", "cs__matrix_8h.html#a9fbdc70ef573548042de9ffdb3cea1cb", null ],
    [ "cs_matrix_structure_destroy", "cs__matrix_8h.html#ae6106f670f30883460a79bf6ce0beda5", null ],
    [ "cs_matrix_transfer_coefficients_msr", "cs__matrix_8h.html#a71ec48134088058c6248e40aadb030e6", null ],
    [ "cs_matrix_variant_apply", "cs__matrix_8h.html#a63fd3c33b395d91a46f4019591be982a", null ],
    [ "cs_matrix_variant_apply_tuned", "cs__matrix_8h.html#a507f11c97b7a5afe7b3ab1ed54bcfecf", null ],
    [ "cs_matrix_variant_build_list", "cs__matrix_8h.html#acd928a6e80527f62277c116b0ab2f2a4", null ],
    [ "cs_matrix_variant_create", "cs__matrix_8h.html#a2c31adca5f530ff4057e8372e47479eb", null ],
    [ "cs_matrix_variant_destroy", "cs__matrix_8h.html#ac5f55a31a521e624c2e27cfef1c94181", null ],
    [ "cs_matrix_variant_set_func", "cs__matrix_8h.html#a6dc7eb11078ddf66892b01614da96fb9", null ],
    [ "cs_matrix_variant_type", "cs__matrix_8h.html#a4f0ba9b19fd81082d3e2d5d1666da423", null ],
    [ "cs_matrix_vector_multiply", "cs__matrix_8h.html#a6e6a607e5adf8e613c540d18b9cd3948", null ],
    [ "cs_matrix_vector_multiply_nosync", "cs__matrix_8h.html#a29aacb5e8290a70355993ccf81422667", null ],
    [ "cs_matrix_vector_multiply_partial", "cs__matrix_8h.html#a4e62adab970f574258c4f23064e35f36", null ],
    [ "cs_matrix_fill_type_name", "cs__matrix_8h.html#a9e5c049cf231d95486c6e3b6b464ab79", null ],
    [ "cs_matrix_spmv_type_name", "cs__matrix_8h.html#a2b699c097fb52aac536f66cd3dcdae57", null ]
];

==> code_saturne-9.1.0-1-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__matrix_8h.js <==
var cs__matrix_8h =
[
    [ "cs_matrix_row_info_t", "structcs__matrix__row__info__t.html", "structcs__matrix__row__info__t" ],
    [ "cs_matrix_structure_t", "cs__matrix_8h.html#a3f726affcdb381ba839a195b62acbb92", null ],
    [ "cs_matrix_t", "cs__matrix_8h.html#a53c593fb2c03dfc5eee5c9a54d895cb4", null ],
    [ "cs_matrix_variant_t", "cs__matrix_8h.html#a08cf016a0506bb404109a18e8e3bb2a5", null ],
    [ "cs_matrix_fill_type_t", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310", [
      [ "CS_MATRIX_SCALAR", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310ab9d5f9e1068cc673a690186129e092e6", null ],
      [ "CS_MATRIX_SCALAR_SYM", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310acada4d09e2a95e0b4f850e672c8887d0", null ],
      [ "CS_MATRIX_BLOCK_D", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310abb2fea01a93c8dd923217e1dd3dacf37", null ],
      [ "CS_MATRIX_BLOCK_D_66", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310a0fe52150bd1561197edcd2a99f910d4a", null ],
      [ "CS_MATRIX_BLOCK_D_SYM", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310ad25d63237d2364ef032500bfef1fefb6", null ],
      [ "CS_MATRIX_BLOCK", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310abd9236e84a7886bc6dfe277e36d89863", null ],
      [ "CS_MATRIX_N_FILL_TYPES", "cs__matrix_8h.html#a9e29e5cec83a6d3065b2c1a33c6f4310a25ac45e1c0bd00980f5d634debf8b2b4", null ]
    ] ],
    [ "cs_matrix_spmv_type_t", "cs__matrix_8h.html#a4469a8e1bec6b446d8bf524f31713c95", [
      [ "CS_MATRIX_SPMV", "cs__matrix_8h.html#a4469a8e1bec6b446d8bf524f31713c95a3463bd22a53462ab0a6b9ff0b57e5e00", null ],
      [ "CS_MATRIX_SPMV_E", "cs__matrix_8h.html#a4469a8e1bec6b446d8bf524f31713c95a8c4a495ce8063fe98be6aa9f1551d4d3", null ],
      [ "CS_MATRIX_SPMV_N_TYPES", "cs__matrix_8h.html#a4469a8e1bec6b446d8bf524f31713c95a0add080683610fa2efb06e2efd16ad82", null ]
    ] ],
    [ "cs_matrix_type_t", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997", [
      [ "CS_MATRIX_NATIVE", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997abd7a07b24725c3c34588ae88adc9b990", null ],
      [ "CS_MATRIX_CSR", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997a1365d45fd66cbc4d1c4e7c5f5602cf2f", null ],
      [ "CS_MATRIX_MSR", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997a337c2f76d768d376d33d8975bf0f487e", null ],
      [ "CS_MATRIX_DIST", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997ac5871f65fee08406348feab4a6436d5b", null ],
      [ "CS_MATRIX_N_BUILTIN_TYPES", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997ae4b62c68b544fa6f0bf2457a0b242ac2", null ],
      [ "CS_MATRIX_N_TYPES", "cs__matrix_8h.html#acd8149f0fddafed8558be1b9dd2a7997a6f7ed530ef30b9cb1f192f043ba999ff", null ]
    ] ],
    [ "cs_matrix_apply_variant", "cs__matrix_8h.html#a8336ea1e2bb9661e28caab372475cb53", null ],
    [ "cs_matrix_assembler_values_init", "cs__matrix_8h.html#ac75dedd257a2e5cc5d22d27de5532f52", null ],
    [ "cs_matrix_copy_diagonal", "cs__matrix_8h.html#a0329bc6e1b44c37148e3a4524156815e", null ],
    [ "cs_matrix_create", "cs__matrix_8h.html#a6c22544898caba8b0c0e37919c8c6958", null ],
    [ "cs_matrix_create_by_copy", "cs__matrix_8h.html#a0e842033f205b9f1b4a7e835f96c208f", null ],
    [ "cs_matrix_create_by_local_restrict", "cs__matrix_8h.html#a88af40c53705779ec36e133eb7119c3f", null ],
    [ "cs_matrix_create_from_assembler", "cs__matrix_8h.html#a730c0f94e05f91bf65a3aede074dfcd4", null ],
    [ "cs_matrix_destroy", "cs__matrix_8h.html#a633b7979992bdf4c3577735862a1975b", null ],
    [ "cs_matrix_get_alloc_mode", "cs__matrix_8h.html#a8606b1bd075ad019e8ee515c6e57120f", null ],
    [ "cs_matrix_get_assembler", "cs__matrix_8h.html#a59ee95248bfc1323cc368f5b30b12f36", null ],
    [ "cs_matrix_get_coefficients_msr_w", "cs__matrix_8h.html#afb7d72c001d2f4b9e254950004d6faa4", null ],
    [ "cs_matrix_get_csr_arrays", "cs__matrix_8h.html#a8553ace49ccaf0d3181b9bd860e9b5db", null ],
    [ "cs_matrix_get_diag_block_size", "cs__matrix_8h.html#ac3af04d2c3b246fa3629662953cc313d", null ],
    [ "cs_matrix_get_diagonal", "cs__matrix_8h.html#a1f0b1821996f0cfb5c797799fa7c2cc0", null ],
    [ "cs_matrix_get_extra_diag_block_size", "cs__matrix_8h.html#a406514787577b41a6c2247f6c0daf236", null ],
    [ "cs_matrix_get_extra_diagonal", "cs__matrix_8h.html#aed92878baa8d0a8fc3fd326dd90bcc61", null ],
    [ "cs_matrix_get_fill_type", "cs__matrix_8h.html#a68debb26743a812111e1bec78d7d17f2", null ],
    [ "cs_matrix_get_halo", "cs__matrix_8h.html#aafd4f3d4863538dfaee65bcac12835d9", null ],
    [ "cs_matrix_get_l_range", "cs__matrix_8h.html#a675887bec0adb9f0384f1628690b35d1", null ],
    [ "cs_matrix_get_mesh_association", "cs__matrix_8h.html#a8f231f765326d168a343a0ecfdeb2b57", null ],
    [ "cs_matrix_get_msr_arrays", "cs__matrix_8h.html#a98cfe74b97c8ab6b8e54abef05a55ab1", null ],
    [ "cs_matrix_get_n_columns", "cs__matrix_8h.html#ae86688001d80341b85d58c8825018b2f", null ],
    [ "cs_matrix_get_n_entries", "cs__matrix_8h.html#a54961bf406b63762241dad3544158efd", null ],
    [ "cs_matrix_get_n_rows", "cs__matrix_8h.html#ae4681eaf0396bc1e723b7f4d3ebd4377", null ],
    [ "cs_matrix_get_native_arrays", "cs__matrix_8h.html#ae9f4142ccd2418b11db757202dbfc418", null ],
    [ "cs_matrix_get_need_xa", "cs__matrix_8h.html#a16530b3e15df9d8076846cde2dcab80f", null ],
    [ "cs_matrix_get_row", "cs__matrix_8h.html#adc6fdbddaced8b5c756df36386f5e1e4", null ],
    [ "cs_matrix_get_type", "cs__matrix_8h.html#adfe3a7a23fddd7c31ff1c071ec51b489", null ],
    [ "cs_matrix_get_type_fullname", "cs__matrix_8h.html#a747648a99a5e4da1f7b0131381eb4452", null ],
    [ "cs_matrix_get_type_name", "cs__matrix_8h.html#a3988db059adfa44213ae1458922c1a19", null ],
    [ "cs_matrix_is_mapped_from_native", "cs__matrix_8h.html#ad1e0fd14b5629863a6830f8fc4a8d65e", null ],
    [ "cs_matrix_is_symmetric", "cs__matrix_8h.html#a0d607988a2fc1e3491bae9d14a633929", null ],
    [ "cs_matrix_pre_vector_multiply_sync", "cs__matrix_8h.html#ac6cb5803fa6d1b9bd5651ab814b468fe", null ],
    [ "cs_matrix_release_coefficients", "cs__matrix_8h.html#ad8cc5a171f95e3c78473516a6080a8d6", null ],
    [ "cs_matrix_release_msr_arrays", "cs__matrix_8h.html#a7d854c9be613651dbe04368687beb85e", null ],
    [ "cs_matrix_row_finalize", "cs__matrix_8h.html#a0050a6f62ba44ecc04d003f9c33be385", null ],
    [ "cs_matrix_row_init", "cs__matrix_8h.html#a95921370bbdca497111adf4a6332e304", null ],
    [ "cs_matrix_set_alloc_mode", "cs__matrix_8h.html#a84a97ba577aa871c439bb73dbf6233e8", null ],
    [ "cs_matrix_set_coefficients", "cs__matrix_8h.html#a1dac07f4baf766157cf15bc2db1f42da", null ],
    [ "cs_matrix_set_mesh_association", "cs__matrix_8h.html#abb52c716fb6b7e6350dd35e0a30a074e", null ],
    [ "cs_matrix_set_need_xa", "cs__matrix_8h.html#a3f384f0d9534075ae7870b69a47a3499", null ],
    [ "cs_matrix_structure_create", "cs__matrix_8h.html#af1d639554baa49b3593ff386f95f27b7", null ],
    [ "cs_matrix_structure_create_from_assembler", "cs__matrix_8h.html#a393a693ad2b00dc8fb08c147d3653f5d", null ],
    [ "cs_matrix_structure_create_msr", "cs__matrix_8h.html#ae5dc01d01c9b5a76ab23057436c4714b", null ],
    [ "cs_matrix_structure_create_msr_shared", "cs__matrix_8h.html#a29580e627b0ee494a8d6c93ad2200d89", null ],
    [ "cs_matrix_structure_destroy", "cs__matrix_8h.html#ae6106f670f30883460a79bf6ce0beda5", null ],
    [ "cs_matrix_structure_release_msr_arrays", "cs__matrix_8h.html#ae560c7c9d66945dd6a2e57aad98f8213", null ],
    [ "cs_matrix_transfer_coefficients", "cs__matrix_8h.html#a62fefc3fa7198834b66cc460e8fd6716", null ],
    [ "cs_matrix_transfer_coefficients_msr", "cs__matrix_8h.html#a71ec48134088058c6248e40aadb030e6", null ],
    [ "cs_matrix_variant_apply", "cs__matrix_8h.html#a63fd3c33b395d91a46f4019591be982a", null ],
    [ "cs_matrix_variant_apply_tuned", "cs__matrix_8h.html#a507f11c97b7a5afe7b3ab1ed54bcfecf", null ],
    [ "cs_matrix_variant_build_list", "cs__matrix_8h.html#acd928a6e80527f62277c116b0ab2f2a4", null ],
    [ "cs_matrix_variant_create", "cs__matrix_8h.html#a39f7ab6944b52c53ad6989d1830c6db4", null ],
    [ "cs_matrix_variant_destroy", "cs__matrix_8h.html#ac5f55a31a521e624c2e27cfef1c94181", null ],
    [ "cs_matrix_variant_set_func", "cs__matrix_8h.html#a6dc7eb11078ddf66892b01614da96fb9", null ],
    [ "cs_matrix_variant_type", "cs__matrix_8h.html#a4f0ba9b19fd81082d3e2d5d1666da423", null ],
    [ "cs_matrix_vector_multiply", "cs__matrix_8h.html#a51d810df84bf96e29d0a695c34d8c553", null ],
    [ "cs_matrix_vector_multiply", "cs__matrix_8h.html#a5d53e60daff297ba0c46cb8283e1a7c4", null ],
    [ "cs_matrix_vector_multiply_nosync", "cs__matrix_8h.html#a567c1a2e5dd9d0869e206ecb07449e38", null ],
    [ "cs_matrix_vector_multiply_partial", "cs__matrix_8h.html#ab785df55ad39e706132f64463ff01700", null ],
    [ "cs_matrix_vector_multiply_partial", "cs__matrix_8h.html#a0a02dea31a5d0b0b70b57317e604570a", null ],
    [ "cs_matrix_fill_type_name", "cs__matrix_8h.html#a9e5c049cf231d95486c6e3b6b464ab79", null ],
    [ "cs_matrix_spmv_type_name", "cs__matrix_8h.html#a2b699c097fb52aac536f66cd3dcdae57", null ]
];
